Package: toxEval
Type: Package
Title: Exploring Biological Relevance of Environmental Chemistry
        Observations
Version: 1.4.2
Authors@R: c(person("Laura", "DeCicco", 
                     role = c("aut","cre"),
                     email = "ldecicco@usgs.gov",
                     comment=c(ORCID="0000-0002-3915-9487")),
              person("Steven", "Corsi", 
                     role = c("aut"),
                     email = "srcorsi@usgs.gov",
                     comment=c(ORCID="0000-0003-0583-5536")),
              person("Daniel", "Villeneuve", 
                     role = c("aut"),
                     comment=c(ORCID="0000-0003-2801-0203")),
              person("Brett", "Blackwell", 
                     role = c("aut"),
                     comment=c(ORCID="0000-0003-1296-4539")), 
              person("Gerald", "Ankley", 
                     role = c("aut"),
                     comment=c(ORCID="0000-0002-9937-615X")), 
              person("Alison", "Appling", 
                     role = "rev", 
                     comment = "Reviewed for USGS"),
              person("Dalma", "Martinovic", 
                     role = "rev", 
                     comment = "Reviewed for USGS"))
Description: Data analysis package for estimating potential biological effects from chemical concentrations in environmental samples. Included are a set of functions to analyze, visualize, and organize measured concentration data as it relates to user-selected chemical-biological interaction benchmark data such as water quality criteria. The intent of these analyses is to develop a better understanding of the potential biological relevance of environmental chemistry data. Results can be used to prioritize which chemicals at which sites may be of greatest concern. These methods are meant to be used as a screening technique to predict potential for biological influence from chemicals that ultimately need to be validated with direct biological assays. A description of the analysis can be found in Blackwell (2017) <doi:10.1021/acs.est.7b01613>.
License: CC0
Copyright: This software is in the public domain because it contains
        materials that originally came from the United States
        Geological Survey, an agency of the United States Department of
        Interior. For more information, see the official USGS copyright
        policy at
        https://www.usgs.gov/visual-id/credit_usgs.html#copyright
Depends: R (>= 4.1.0)
Imports: dplyr, tidyr, DT (>= 0.1.24), leaflet (>= 1.0.0), ggplot2 (>=
        3.0.0), magrittr, shiny, shinydashboard, RColorBrewer, readxl,
        tools, shinyAce, shinycssloaders, utils
Suggests: rmarkdown, testthat, knitr, here, tcpl, openxlsx, covr
BugReports: https://github.com/DOI-USGS/toxEval/issues
VignetteBuilder: knitr
BuildVignettes: true
LazyLoad: yes
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-01-23 20:01:30 UTC; ldecicco
Author: Laura DeCicco [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-3915-9487>),
  Steven Corsi [aut] (ORCID: <https://orcid.org/0000-0003-0583-5536>),
  Daniel Villeneuve [aut] (ORCID:
    <https://orcid.org/0000-0003-2801-0203>),
  Brett Blackwell [aut] (ORCID: <https://orcid.org/0000-0003-1296-4539>),
  Gerald Ankley [aut] (ORCID: <https://orcid.org/0000-0002-9937-615X>),
  Alison Appling [rev] (Reviewed for USGS),
  Dalma Martinovic [rev] (Reviewed for USGS)
Maintainer: Laura DeCicco <ldecicco@usgs.gov>
Repository: CRAN
Date/Publication: 2026-01-23 20:30:02 UTC
Built: R 4.6.0; ; 2026-04-30 05:19:50 UTC; unix
