# Generated by roxygen2: do not edit by hand

S3method(summary,toxEval)
export(ToxCast_ACC)
export(as.toxEval)
export(clean_endPoint_info)
export(createLink)
export(create_toxEval)
export(end_point_info)
export(endpoint_hits)
export(endpoint_hits_DT)
export(explore_endpoints)
export(filter_groups)
export(flags)
export(get_ACC)
export(get_chemical_summary)
export(get_concentration_summary)
export(graph_chem_data)
export(hits_by_groupings)
export(hits_by_groupings_DT)
export(hits_summary)
export(hits_summary_DT)
export(make_tox_map)
export(map_tox_data)
export(plot_chemical_boxplots)
export(plot_tox_boxplots)
export(plot_tox_endpoints)
export(plot_tox_endpoints2)
export(plot_tox_heatmap)
export(plot_tox_stacks)
export(rank_sites)
export(rank_sites_DT)
export(remove_flags)
export(side_by_side_data)
export(tox_boxplot_data)
export(tox_chemicals)
import(ggplot2)
import(shinydashboard)
importFrom(grDevices,colorRampPalette)
importFrom(magrittr,"%>%")
importFrom(shinyAce,aceEditor)
importFrom(shinyAce,updateAceEditor)
importFrom(shinycssloaders,withSpinner)
importFrom(tools,file_ext)
